<?php

namespace EventPortal\Domain\Event\Form\Requests;

use EventPortal\Domain\Event\Form\Enums\FormType;
use EventPortal\Domain\Event\Form\Enums\QuestionType;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\ValidationException;
use Spatie\Enum\Laravel\Http\Requests\TransformsEnums;

class UpdateFormRequest extends FormRequest
{
    use TransformsEnums;

    public function authorize(): bool
    {
        return true;
    }

    public function rules(): array
    {
        return [
            'name' => 'required',
            'type' => 'required',
            'type.value' => 'required|enum:' . FormType::class,
            'steps.*.name' => 'required',
            'steps.*.order' => 'required|integer',
            'steps.*.uuid' => 'required|uuid',
            'steps.*.sections.*.name' => 'required',
            'steps.*.sections.*.order' => 'required|integer',
            'steps.*.sections.*.uuid' => 'required|uuid',
            'steps.*.sections.*.questions.*.question' => 'required',
            'steps.*.sections.*.questions.*.order' => 'required|integer',
            'steps.*.sections.*.questions.*.uuid' => 'required|uuid',
            'steps.*.sections.*.questions.*.component' => 'required',
            'steps.*.sections.*.questions.*.component.name' => 'required',
            'steps.*.sections.*.questions.*.component.name.value' => 'required|enum:' . QuestionType::class,
            'steps.*.sections.*.questions.*.required' => 'required|boolean',
            'steps.*.sections.*.questions.*.options.*.value' => 'required',
            'steps.*.sections.*.questions.*.options.*.order' => 'required|integer',
            'steps.*.sections.*.questions.*.options.*.uuid' => 'required|uuid',
            'steps.*.sections.*.questions.*.validations.*.rule' => 'required',
            'steps.*.sections.*.questions.*.validations.*.message' => 'required',
        ];
    }

    protected function failedValidation(Validator $validator): void
    {
        toast()->error('Malformed data provided');

        throw (new ValidationException($validator))
            ->errorBag($this->errorBag)
            ->redirectTo($this->getRedirectUrl());
    }

    public function enums(): array
    {
        return [
            'type.value' => FormType::class,
            'steps.*.sections.*.questions.*.component.name.value' => QuestionType::class,
        ];
    }
}
