<?php

namespace EventPortal\Domain\Event\ValueObjects;

use EventPortal\Domain\Event\Models\Event;

class EventDetails
{
    /** @var string */
    public $name;

    /** @var string */
    public $description;

    /** @var string */
    public $date;

    /** @var string */
    public $startDate;

    /** @var string */
    public $status;

    /** @var array */
    public $buttons;

    public function __construct(Event $event, ?array $buttons = null)
    {
        $this->name = $event->name;
        $this->description = $event->description;
        $this->date = $event->readable_dates;
        $this->startDate = optional($event->start_date)->format('d/m/Y');
        $this->isVirtual = $event->is_virtual;
        $this->status = $event->readable_status;
        $this->buttons = $buttons;
    }

    public static function make(Event $event, ?array $buttons = null): self
    {
        return new self($event, $buttons);
    }

    public function toArray(): array
    {
        return [
            'name' => $this->name,
            'description' => $this->description,
            'date' => $this->date,
            'startDate' => $this->startDate,
            'status' => $this->status,
            'buttons' => $this->buttons,
        ];
    }
}
