<?php

namespace EventPortal\Http\Controllers\Admin\EventVenue;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Eloquent\Builder;
use Inertia\Response;

class VenuesNotOnEventController extends Controller
{
    public function __invoke(Event $event): Response
    {
        $query = Venue::query()
            ->whereDoesntHave('events', static function (Builder $query) use ($event): Builder {
                return $query->where('events.id', '=', $event->id);
            });

        $table = Table::make('event-venue.add')
            ->context($event)
            ->query($query)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Venues', route('admin.event.venue.index', $event))
            ->add('Add Venue')
            ->get();

        return AdminRender::component('Admin/EventVenue/Add')
            ->key('event.venue.add')
            ->withTable($table)
            ->withBreadcrumbs($breadcrumbs)
            ->attributes(['event' => $event])
            ->get();
    }
}
