<?php

namespace EventPortal\Tests\Unit\Event\ValueObjects;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\ValueObjects\PageHeader;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\TestCase;

class PageHeaderTest extends TestCase
{
    /** @test **/
    public function can_add_title()
    {
        $pageHeader = PageHeader::make()->title('Page Title');

        $this->assertSame('Page Title', $pageHeader->title);
    }

    /** @test **/
    public function can_add_description()
    {
        $pageHeader = PageHeader::make()->description('Page Description');

        $this->assertSame('Page Description', $pageHeader->description);
    }

    /** @test **/
    public function can_add_call_to_action()
    {
        $callToAction = Button::make('Call To Action')
            ->method(InertiaMethod::VISIT())
            ->route('home');

        $pageHeader = PageHeader::make()->callToAction($callToAction);

        $this->assertSame($callToAction, $pageHeader->callToAction);
    }

    /** @test **/
    public function can_chain_method_calls()
    {
        $callToAction = Button::make('Call To Action')
            ->method(InertiaMethod::VISIT())
            ->route('home');

        $pageHeader = PageHeader::make()
            ->title('Page Title')
            ->description('Page Description')
            ->callToAction($callToAction);

        $this->assertSame('Page Title', $pageHeader->title);
        $this->assertSame('Page Description', $pageHeader->description);
        $this->assertSame($callToAction, $pageHeader->callToAction);
    }
}
